<?php
/*
Plugin Name: EasyCPMods Toolbox
Plugin URI: http://www.easycpmods.com
Description: EasyCPMods Toolbox is a free plugin for those who use EasyCPMods plugins. It allows grouping plugins into one group and will check for EasyCPMods plugin updates.
Author: EasyCPMods
Version: 1.2.7
Author URI: http://www.easycpmods.com
Text Domain: ecpm-etb
*/

define('ECPM_ETB_NAME', 'EasyCPMods Toolbox');
define('ECPM_ETB', 'ecpm-etb');
define('ECPM_ETB_VERSION', '1.2.7');
//define('ECPM_ETB_API_URL', 'http://192.168.2.15/ecpmdev/ecpm-check/');
define('ECPM_ETB_API_URL', 'http://easycpmods.com/ecpm-check/');

register_activation_hook( __FILE__, 'ecpm_etb_activate');
register_deactivation_hook( __FILE__, 'ecpm_etb_deactivate');
//register_uninstall_hook( __FILE__, 'ecpm_etb_uninstall');

add_action('admin_enqueue_scripts', 'ecpm_etb_enqueue_scripts');
add_action('ecpm_toolbox_event', 'ecpm_etb_toolbox_event');

//add_action('admin_init', 'ecpm_etb_settings_init');
add_action('admin_menu', 'ecpm_etb_options_page');

/**
 * custom option and settings
 */
function ecpm_etb_settings_init() {
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
  if ($ecpm_etb_settings['group_settings'] == 'on') {
    //register_setting( 'ecpm-menu', 'ecpm_etb_options' );
  }  
}
 
/**
 * top level menu
 */
function ecpm_etb_options_page() {
  $update_icon = '';
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
  if ($ecpm_etb_settings['group_settings'] == 'on') {
    if ($ecpm_etb_settings['update_available'] === true)
      $update_icon = '<span class="etb-update"></span>';
    
    add_menu_page( 'EasyCPMods', 'EasyCPMods'.$update_icon, 'manage_options', 'ecpm-menu', 'ecpm_etb_settings_page_callback' );
    add_submenu_page( 'ecpm-menu', ECPM_ETB_NAME, ECPM_ETB_NAME, 'manage_options', 'ecpm_etb_settings_page', 'ecpm_etb_settings_page_callback' );
  } else {
    add_options_page(ECPM_ETB_NAME, ECPM_ETB_NAME, 'manage_options', 'ecpm_etb_settings_page', 'ecpm_etb_settings_page_callback');
  }  
}
 

function ecpm_etb_activate() {
  if (ecpm_etb_check_plugins() == false)
    return;
    
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
  if ( empty($ecpm_etb_settings) ) {
    $ecpm_etb_settings = array(
      'group_settings' => 'on',
      'check_update' => 'weekly',
      'api_key' => '',
      'plugin_data' => array(),
      'update_available' => false,
      'show_count' => '4',
      'key_status' => '',
      'key_error' => '',
    );
    update_option( 'ecpm_etb_settings', $ecpm_etb_settings );
  }
}

function ecpm_etb_deactivate(){
  wp_clear_scheduled_hook('ecpm_etb_toolbox_event');
}

function ecpm_etb_plugins_loaded() {
  $dir = dirname(plugin_basename(__FILE__)).DIRECTORY_SEPARATOR.'languages'.DIRECTORY_SEPARATOR;
	load_plugin_textdomain(ECPM_ETB, false, $dir);
}

function ecpm_etb_enqueue_scripts()	{
  wp_enqueue_style('ecpm_etb_style', plugins_url('ecpm-etb.css', __FILE__), array(), null);
}

function ecpm_etb_toolbox_event($manual_call = false){
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
  if (empty($ecpm_etb_settings['api_key']))
    return;
  
  $api_key = $ecpm_etb_settings['api_key'];
  
  $installed_plugins = ecpm_etb_check_plugins();
  
  $ecpm_etb_settings['plugin_data'] = array();
  $ecpm_etb_settings['update_available'] = false;
  
  foreach ($installed_plugins as $plugin) {
    $response = wp_remote_get( ECPM_ETB_API_URL.$plugin.'?key='.$api_key );

    if( is_array($response) ) {
      //$header = $response['headers']; // array of http header lines
      $body = $response['body']; // use the content
      //echo print_r($header);
      //echo $body;
      
      $plugin_data = json_decode( $body, true);

      if (is_array($plugin_data)) {
        if (isset($plugin_data['error'])) {
          if ($manual_call) 
            echo scb_admin_notice( $plugin_data['error'], 'error' );
            
          if ( in_array($plugin_data['error_type'], array('2', '4')) ) {
            if ($plugin_data['error_type'] == '4')
              $ecpm_etb_settings['key_status'] = 'disabled';
            else  
              $ecpm_etb_settings['key_status'] = false;
              
            $ecpm_etb_settings['key_error'] = $plugin_data['error'];
          }  
        } else {
          $ecpm_etb_settings['plugin_data'][] = array(
            'plugin_code' => $plugin_data['code'], 
            'plugin_version' => $plugin_data['version']
            );
          
          $latest_version = ecpm_etb_check_latest($plugin_data['code'], $ecpm_etb_settings);
          if ($latest_version !== true)
            $ecpm_etb_settings['update_available'] = true;
          
          $ecpm_etb_settings['key_status'] = true;
          $ecpm_etb_settings['key_error'] = '';    
        }  
      }  
    }
  }
  
  update_option( 'ecpm_etb_settings', $ecpm_etb_settings );
}

function ecpm_etb_get_plugin_array($plugin_code = ''){
  $plugins = array(
    'oca' => array('url' => '1-click-bump-renew', 'path' => '1-click-bump-renew', 'file' => 'ecpm-oca.php', 'name' => '1-Click Bump Renew'), 
    'agc' => array('url' => 'plugin-add-gateway-charges', 'path' => 'add-gateway-charges', 'file' => 'ecpm-agc.php', 'name' => 'Add Gateway Charges'),
    'abr' => array('url' => 'auto-bump-renew', 'path' => 'auto-bump-renew', 'file' => 'ecpm-abr.php', 'name' => 'Auto Bump Renew'),
    'bpe' => array('url' => 'plugin-basic-post-expiration', 'path' => 'basic-post-expiration', 'file' => 'ecpm-bpe.php', 'name' => 'Basic Post Expiration'),
    'bfs' => array('url' => 'plugin-better-featured-slider', 'path' => 'better-featured-slider', 'file' => 'ecpm-bfs.php', 'name' => 'Better Featured Slider'),
    'bua' => array('url' => 'plugin-block-user-ads', 'path' => 'block-user-ads', 'file' => 'ecpm-bua.php', 'name' => 'Block User Ads'),
    'cao' => array('url' => 'plugin-cp-author-online', 'path' => 'cp-author-online', 'file' => 'ecpm-cao.php', 'name' => 'CP Author Online'),
    'cfs' => array('url' => 'plugin-cp-field-shortcodes', 'path' => 'cp-field-shortcodes', 'file' => 'ecpm-cfs.php', 'name' => 'CP Field Shortcodes'),
    'cpl' => array('url' => 'plugin-cp-phone-link', 'path' => 'cp-phone-link', 'file' => 'ecpm-cpl.php', 'name' => 'CP Phone Link'),
    'cfd' => array('url' => 'plugin-custom-field-data-icons', 'path' => 'custom-field-data-icons', 'file' => 'ecpm-cfd.php', 'name' => 'Custom Field Data Icons'),
    'cfdp' => array('url' => 'plugin-custom-field-data-icons-pro', 'path' => 'custom-field-data-icons-pro', 'file' => 'ecpm-cfd-pro.php', 'name' => 'Custom Field Data Icons PRO'),
    'ecp' => array('url' => 'plugin-easy-credit-payments', 'path' => 'easy-credit-payments', 'file' => 'ecpm-ecp.php', 'name' => 'Easy Credit Payments'),
    'eve' => array('url' => 'plugin-easy-video-embed', 'path' => 'easy-video-embed', 'file' => 'ecpm-eve.php', 'name' => 'Easy Video Embed'),
    'ddc' => array('url' => 'plugin-faster-with-stats', 'path' => 'faster-with-stats', 'file' => 'ecpm-ddc.php', 'name' => 'Faster with Stats'),
    'fpe' => array('url' => 'plugin-featured-post-expiration', 'path' => 'featured-post-expiration', 'file' => 'ecpm-fpe.php', 'name' => 'Featured Post Expiration'),
    'ham' => array('url' => 'plugin-hide-ads-to-members', 'path' => 'hide-ads-to-members', 'file' => 'ecpm-ham.php', 'name' => 'Hide Ads to Members'),
    'moa' => array('url' => 'plugin-minimum-order-amount', 'path' => 'minimum-order-amount', 'file' => 'ecpm-moa.php', 'name' => 'Minimum Order Amount'),
    'pae' => array('url' => 'plugin-paid-ad-extender', 'path' => 'paid-ad-extender', 'file' => 'ecpm-pae.php', 'name' => 'Paid Ad Extender'),
    'paf' => array('url' => 'plugin-paid-ad-features', 'path' => 'paid-ad-features', 'file' => 'ecpm-paf.php', 'name' => 'Paid Ad Features'),
    'pgi' => array('url' => 'plugin-payment-gateway-icons', 'path' => 'paygate-icons', 'file' => 'paygate-icons.php', 'name' => 'Payment Gateway Icons'),
    'qrc' => array('url' => 'plugin-qr-code-tab', 'path' => 'qr-code-tab', 'file' => 'qr-code-tab.php', 'name' => 'QR Code Tab'),
    'rdi' => array('url' => 'plugin-remove-detached-images', 'path' => 'remove-detached-images', 'file' => 'ecpm-rdi.php', 'name' => 'Remove Deatched Images'),
    'ual' => array('url' => 'plugin-user-ads-limiter', 'path' => 'user-ads-limiter', 'file' => 'ecpm-ual.php', 'name' => 'User Ads Limiter'),
    'ilr' => array('url' => 'plugin-image-loop-randomize', 'path' => 'image-loop-randomize', 'file' => 'ecpm-ilr.php', 'name' => 'Image Loop Randomize'),
    'eqc' => array('url' => 'plugin-easy-qr-codes', 'path' => 'easy-qr-codes', 'file' => 'ecpm-eqc.php', 'name' => 'Easy QR Codes'),
  );
  
  if ($plugin_code)
    return $plugins[$plugin_code];
  else  
    return $plugins;
}

function ecpm_etb_check_plugins(){
  $active_plugins = array();
  
  $plugins = ecpm_etb_get_plugin_array();
  
  foreach ($plugins as $key => $plugin){
    if ( is_plugin_active($plugin['path'].'/'.$plugin['file']) || file_exists(ABSPATH . 'wp-content/plugins/'.$plugin['path'].'/'.$plugin['file']) )
      $active_plugins[] = $key;
  }
    
  if (empty($active_plugins))
    return false;  
  else {
    return $active_plugins;
  }    
}

function ecpm_etb_check_latest($plugin_code, $ecpm_etb_settings){
  $plugin_etb_data = ecpm_etb_get_plugin_array($plugin_code);
  $plugin_file = ABSPATH . 'wp-content/plugins/' .$plugin_etb_data['path'].'/'.$plugin_etb_data['file'];
  $plugin_data = get_plugin_data( $plugin_file );
  
  if (isset($ecpm_etb_settings['plugin_data'])) {
    foreach ($ecpm_etb_settings['plugin_data'] as $plugin) {
      if ($plugin['plugin_code'] == $plugin_code ) {
        break;
      }
    }
  } else {
    return false;
  } 
  
  if (!isset($plugin))
    return false;
    
  if ($plugin_data['Version'] != $plugin['plugin_version'])
    return $plugin['plugin_version'];
  else
    return true;  
}

function ecpm_etb_settings_page_callback() {
  $ecpm_etb_settings = get_option('ecpm_etb_settings');
	
  if ( current_user_can( 'manage_options' ) ) {
    if( isset( $_POST['ecpm_etb_submit_check'] ) ) {
      ecpm_etb_toolbox_event(true);
    
    } elseif( isset( $_POST['ecpm_etb_submit_api'] ) ) {
      $response = wp_remote_get( ECPM_ETB_API_URL.'newkey?url='.get_site_url() );
  
      if( is_array($response) ) {
        $received_data = json_decode( $response['body'], true);
        if (isset($received_data['error'])) {
          $ecpm_etb_settings['key_status'] = false;
          $ecpm_etb_settings['key_error'] = $received_data['error'];
          echo scb_admin_notice( $received_data['error'], 'error' );
        } else {
          $ecpm_etb_settings['api_key'] = $received_data['api_key'];
          $ecpm_etb_settings['key_status'] = true;
          $ecpm_etb_settings['key_error'] = '';
        }
        update_option( 'ecpm_etb_settings', $ecpm_etb_settings );  
      }
    
    } elseif (isset($_POST['ecpm_etb_submit_checkkey'] ) ) {
      $response = wp_remote_get( ECPM_ETB_API_URL.'checkkey?key='.$ecpm_etb_settings['api_key'].'&url='.get_site_url() );
  
      if( is_array($response) ) {
        $received_data = json_decode( $response['body'], true);
        if (isset($received_data['key_status']) && $received_data['key_status'] == true ) {
          $ecpm_etb_settings['key_status'] = true;
          $ecpm_etb_settings['key_error'] = '';
          echo scb_admin_notice( __( 'You API key is OK.', ECPM_ETB ), 'updated' );
        } elseif (isset($received_data['error'])) {
            if ($received_data['error_type'] == '4')
              $ecpm_etb_settings['key_status'] = 'disabled';
            else  
              $ecpm_etb_settings['key_status'] = false;
              
          $ecpm_etb_settings['key_error'] = $received_data['error'];
          echo scb_admin_notice( $received_data['error'], 'error' );
        } 
        update_option( 'ecpm_etb_settings', $ecpm_etb_settings );
      }
      
    } elseif( isset( $_POST['ecpm_etb_submit'] ) ) {
      $update_freq_values = array('daily', 'weekly', 'never');
      
      if (isset($_POST[ 'ecpm_group_settings' ]) && $_POST[ 'ecpm_group_settings' ] == 'on')
        $ecpm_etb_settings['group_settings'] = $_POST[ 'ecpm_group_settings' ];
      else
        $ecpm_etb_settings['group_settings'] = '';
      
      if ( in_array($_POST[ 'ecpm_etb_check_update' ], $update_freq_values) ) { 
        $ecpm_etb_settings['check_update'] = sanitize_text_field($_POST[ 'ecpm_etb_check_update' ]);
        
        wp_clear_scheduled_hook('ecpm_toolbox_event');
        
        if ($ecpm_etb_settings['check_update'] != 'never')
          wp_schedule_event( current_time( 'timestamp' ), $ecpm_etb_settings['check_update'], 'ecpm_toolbox_event');  
      
        
      }
      
      if ( is_numeric(intval( $_POST[ 'ecpm_etb_show_count' ] )) ) {
        $ecpm_etb_settings['show_count'] = $_POST[ 'ecpm_etb_show_count' ];
      }
        
      update_option( 'ecpm_etb_settings', $ecpm_etb_settings );
      
      echo scb_admin_notice( __( 'Settings saved.', APP_TD ), 'updated' );
    }
  }      

  $key_status = $ecpm_etb_settings['key_status'];
  $installed_plugins = ecpm_etb_check_plugins();
  $all_plugins = ecpm_etb_get_plugin_array();
    
  ?>
  
	<div id="fassetting">
		<div class="wrap">
			<h1><?php echo _e('EasyCpMods Toolbox Settings', ECPM_ETB); ?></h1>
      <?php
      echo "<i>Plugin version: <u>".ECPM_ETB_VERSION."</u>";
      echo "<br>Plugin language file: <u>ecpm-etb-".get_locale().".mo</u></i>";
      ?>
			<hr>
        <table width="1000px" cellspacing="0" cellpadding="8" border="0">  
          <tr>
  					<td width="2px" class="etb-key-status-<?php echo ($key_status === true ? 'ok':'notok');?>">
              
            </td>
            <th align="left">
  						<label for="ecpm_api_key"><?php echo _e('EasyCPMods update API key', ECPM_ETB); ?></label>
  					</th>
  					<td>
              <Input disabled type='text' size='20' Name ='ecpm_api_key' value='<?php echo esc_html($ecpm_etb_settings['api_key']);?>'>
  				  </td>
            <td align="left">
              <?php
              if ($key_status !== true) {
                if ($key_status != 'disabled') {
              ?>	
                <form id='etbkeyform' method="post" action="">
                  <input type="submit" id="ecpm_etb_submit_api" name="ecpm_etb_submit_api" class="button-primary" value="<?php _e('Get your free API key', ECPM_ETB); ?>" />
                </form>  
                <?php 
                } else {
                  echo $ecpm_etb_settings['key_error'];
                ?>  
                  <form id='etbkeycheckform' method="post" action="">
                    <input type="submit" id="ecpm_etb_submit_checkkey" name="ecpm_etb_submit_checkkey" class="button-primary" value="<?php _e('Check your key', ECPM_ETB); ?>" />
                  </form>
                <?php
                }
              } else {
              ?>  
                <form id='etbkeycheckform' method="post" action="">
                  <input type="submit" id="ecpm_etb_submit_checkkey" name="ecpm_etb_submit_checkkey" class="button-primary" value="<?php _e('Check your key', ECPM_ETB); ?>" />
                </form>
              <?php
              }  
              ?>
  					</td>
  				</tr>
        </table>
      <hr>
      <?php
      if (isset($ecpm_etb_settings['api_key']) && $key_status === true) {
      ?>
        <table width="100%" cellspacing="0" cellpadding="8" border="0">  
          <form id='etbsettingform' method="post" action="">
          <tr>
  					<th align="left">
  						<label for="ecpm_group_settings"><?php echo _e('Group all EasyCPMods plugins in one settings group', ECPM_ETB); ?></label>
  					</th>
  					<td>
              <Input type='checkbox' id='ecpm_group_settings' Name='ecpm_group_settings' <?php echo ($ecpm_etb_settings['group_settings'] == 'on' ? 'checked':'') ;?> >
  				  </td>
            <td>		
              <span class="description"><?php _e( 'Easy CP Mods plugins will not appear on Settings group but in a separate group called EasyCPMods' , ECPM_ETB ); ?></span>
  					</td>
  				</tr>
          
          <tr>
      			<th align="left">
      				<label for="ecpm_etb_check_update"><?php echo _e('Check for EasyCPMods plugin updates', ECPM_ETB); ?></label>
      			</th>
      			<td align="left">
      				<select id='ecpm_etb_check_update' name="ecpm_etb_check_update">
                <option value="never" <?php echo ($ecpm_etb_settings['check_update'] == 'never' ? 'selected':'') ;?>><?php _e('Never', ECPM_ETB);?></option>
                <option value="daily" <?php echo ($ecpm_etb_settings['check_update'] == 'daily' ? 'selected':'') ;?>><?php _e('Daily', ECPM_ETB);?></option>
                <option value="weekly" <?php echo ($ecpm_etb_settings['check_update'] == 'weekly' ? 'selected':'') ;?>><?php _e('Weekly', ECPM_ETB);?></option>
              </select>
            </td>
            <td>  
              <span class="description"><?php _e( 'Specify frequency for checking EasyCPMods plugin updates' , ECPM_ETB ); ?></span>
      			</td>
      		</tr>
          
          <tr>
      			<th align="left">
      				<label for="ecpm_etb_show_count"><?php echo _e('Number of plugin icons per line', ECPM_ETB); ?></label>
      			</th>
      			<td align="left">
      				<select id='ecpm_etb_show_count' name="ecpm_etb_show_count">
                <?php
                for ($i=2; $i<=6; $i++) {
                ?>
                <option value="<?php echo $i;?>" <?php echo ($ecpm_etb_settings['show_count'] == $i ? 'selected':'') ;?>><?php echo $i;?></option>
                <?php
                }
                ?>
              </select>
            </td>
            <td>  
              <span class="description"><?php _e( 'How many icons should be shown in one line' , ECPM_ETB ); ?></span>
      			</td>
      		</tr>
          
          <tr>
            <td colspan="3"> 
              <hr>
            	<p class="submit">
            	<input type="submit" id="ecpm_etb_submit" name="ecpm_etb_submit" class="button-primary" value="<?php _e('Save settings', ECPM_ETB); ?>" />
            	</p>
            </td>
          </tr>
          </form>
        
         
          <tr>
            <td colspan="3">
               <h3><?php echo _e('Currently installed EasyCPMods plugins', ECPM_ETB); ?></h3>
               <table cellspacing="0" cellpadding="10">
                 <tr>
                 <?php 
                 $hor_counter = 0;
                 if (!empty($installed_plugins)) {
                   foreach ($all_plugins as $key => $plugin) {
                     if (!in_array($key, $installed_plugins ) )
                       continue;
                   ?>
                     <td>
                       <table width="100%" cellspacing="0" cellpadding="0" border="0">
                         <tr>
                           <td width="266px">
                             <a href="https://www.easycpmods.com/<?php echo esc_html($plugin['url']);?>/" target="_blank"><img src="<?php echo esc_url(plugins_url('images/'.esc_html($plugin['path']).'.png', __FILE__));?>" border="0" width="267px" height="126px" title="<?php echo esc_html($plugin['name']);?>" alt="<?php echo esc_html($plugin['name']);?>"></a>
                           </td>
                         </tr>
                         <tr>
                             <?php
                             $latest_version = ecpm_etb_check_latest($key, $ecpm_etb_settings);
                             if ($latest_version === true) {
                               echo '<td width="266px" class="etb-status etb-updated">'. __('You have the latest version', ECPM_ETB).'</td>';
                             } else {
                               echo '<td width="266px" class="etb-status etb-not-updated">'. __('Newer version of this plugin is available', ECPM_ETB).' ('.$latest_version.')</td>';
                             }
                             ?>
                         </tr>
                       </table>    
                     </td>  
                   <?php
                     $hor_counter++;
                     if ($hor_counter % $ecpm_etb_settings['show_count'] == 0){
                       echo '</tr><tr>';
                     }
                   }
                 }  
                 ?>
                 </tr>
               </table>
            </td>
          </tr>
          
          <tr>      
            <td colspan="3">
            <form id='etbcheckform' method="post" action="">
              <p>		
                <input type="submit" id="ecpm_etb_submit_check" name="ecpm_etb_submit_check" class="button-primary" value="<?php _e('Check for updates now', ECPM_ETB); ?>" />
              </p>  
        			
            </form>
            </td>
          </tr>
          
          <tr>
            <td colspan="3">
               <h3><?php echo _e('Other EasyCPMods plugins you can install', ECPM_ETB); ?></h3>
               <table cellspacing="0" cellpadding="10">
                 <tr>
                 <?php 
                 $hor_counter = 0;
                 foreach ($all_plugins as $key => $plugin) {
                   if (!empty($installed_plugins) && in_array($key, $installed_plugins ) ) 
                     continue;
                 ?>
                   <td>
                     <table width="100%" cellspacing="0" cellpadding="0" border="0">
                       <tr>
                         <td width="266px">
                           <a href="http://www.easycpmods.com/<?php echo esc_html($plugin['url']);?>/" target="_blank"><img src="<?php echo esc_url(plugins_url('images/'.esc_html($plugin['path']).'.png', __FILE__));?>" border="0" width="267px" height="126px" title="<?php echo esc_html($plugin['name']);?>" alt="<?php echo esc_html($plugin['name']);?>"></a>
                         </td>
                       </tr>
                       <tr>
                           <?php
                             echo '<td width="266px" class="etb-status etb-not-installed">'. esc_html($plugin['name']).'</td>';
                           ?>
                       </tr>
                     </table>    
                   </td>  
                 <?php
                   $hor_counter++;
                   if ($hor_counter % $ecpm_etb_settings['show_count'] == 0){
                     echo '</tr><tr>';
                   }
                 }
                 ?>
                 </tr>
               </table>
            </td>
          </tr>
        </table>
        
      <?php
      } 
      ?>  
		</div>
	</div>
<?php
}
?>